<?php

/**
 * @version    4.0.1
 * @package    TAGZ
 * @author     roosterz.nl <roy@roosterz.nl>
 * @copyright  2020 roosterz.nl
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;

use Joomla\Registry\Registry;

/**
 * Tagz helper.
 *
 * @since  1.6
 */
class TagzHelper
{
    /**
	 *  Plugin Params
	 *
	 *  @var  JRegistry
	 */
	public static $params;

	public static function checkAMPZNotInstalled()
	{
		if (JComponentHelper::isEnabled('com_ampz', true))
		{
			return false;
		}
		else {
			return true;
		}
	}

	public static function getTagInfo($component_id, $component_type)
	{
		$structure = TagzHelper::getContentTypeStructure($component_type);
		$config_params = TagzHelper::getParams();

		$db = JFactory::getDBO();

		$select_array = array($db->quoteName($structure['title'], 'title'), $db->quoteName($structure['description'], 'description'));

        if ($component_type != "k2" && $component_type != "virtuemart" && $component_type != "hikashop" && $component_type != "zoo" && $component_type != "jticketing" && $component_type != "eshop" && $component_type != "opencart") { // No direct access to images in database
            array_push($select_array, $db->quoteName($structure['image'], 'image'));
        }
		if ($component_type == "zoo") {
			array_push($select_array, $db->quoteName('application_id', 'application_id'));
			array_push($select_array, $db->quoteName('type', 'type'));
		}

		if ($component_type != "opencart") {
			$structure['table'] = '#__' . $structure['table'];
		}

		$query = $db->getQuery(true);
		$query
            ->select($select_array)
            ->from($db->quoteName($structure['table']))
            ->where($db->quoteName($structure['id']) . ' = ' . $db->quote($component_id));

        $db->setQuery($query);
        $results = $db->loadAssoc();

		if ($component_type == "content") {
			if ($results['fulltext'] != '') {
				$results['description'] = $results['description'] . $results['fulltext'];
			}

			$images = json_decode($results['image']);

            if ($images->image_fulltext != "") // Full Text image prevails above intro image
                $results['image'] = $images->image_fulltext;
            else if ($images->image_intro != "")
                $results['image'] = $images->image_intro;
            else
                $results['image'] = "";
        }
		else if ($component_type == "zoo") {
			$zoo_elements = json_decode($results['description'], true);
			$zoo_application_type = $results['type'];

			$zooCustomTypesEnabled = $config_params->get("enable_zoo_custom_types");
			if ($zooCustomTypesEnabled) {
				for ($i = 1; $i <= 10 ; $i++) {
					$var = "custom_" . $i;
					$zooCustomType = $config_params->get($var);

					if ($zooCustomType == '') { // Stop since the next custom type isn't filled out
						break;
					}

					if ($zoo_application_type == $zooCustomType) {
						$zoo_application_type = "custom_" . $i;
						break;
					}
				}
			}

			$zoo_application_type_description = 'zoo_' . $zoo_application_type . '_description_string';
			$zoo_application_type_image = 'zoo_' . $zoo_application_type . '_image_string';

			$zooDescriptionString = $config_params->get($zoo_application_type_description);
			$zooImageString = $config_params->get($zoo_application_type_image);

			$results['description'] = $zoo_elements[$zooDescriptionString][0]["value"];
			$results['image'] = $zoo_elements[$zooImageString]["file"];
			if (!isset($results['image'])) {
				$results['image'] =  $zoo_elements[$zooImageString][0]["file"];
			}
		}
        else if ($component_type == "jomclassifieds") {
            // jomclassifieds can store multiple images in the same Table field
            $images = $results['image'];
            $results['image'] = substr($images, 0, strpos($images, ','));
        }
        else if ($component_type == "rseventspro") {
			if (isset($result['image'])) {
				$image = $results['image'];
	            $results['image'] = 'components/com_rseventspro/assets/images/events/' . $image;
			}
			else {
				$results['image'] = "";
			}
        }
        else if ($component_type == "easyblog") {
            // Easyblog uses different ways to store images in several folders
            $full_image = $results['image'];

            if (strpos($full_image, 'post:', 0) !== false) {
                $image = substr($full_image, 5);
                $results['image'] = 'images/easyblog_articles/' . $image;
            }
            else if (strpos($full_image, 'user:', 0) !== false) {
                $image = substr($full_image, 5);
                $results['image'] = 'images/easyblog_images/' . $image;
            }
            else if (strpos($full_image, 'shared/', 0) !== false) {
                $image = substr($full_image, 7);
                $results['image'] = 'images/easyblog_shared/' . $image;
            }
        }
        else if ($component_type == "k2") {
            if (JFile::exists(JPATH_SITE.'/media/k2/items/cache/'.md5("Image".$component_id).'_XL.jpg')) {
                $results['image'] = 'media/k2/items/cache/'.md5("Image".$component_id).'_XL.jpg';
            } else {
                $results['image'] = '';
            }
        }
		else if ($component_type == "rsblog") {
			$image = $results['image'];
			if (strpos($image, '[images]blog/', 0) === 0) {
				$image = substr($image, 13);
				$results['image'] = 'images/blog/' . $image;
			}
			else {
				$results['image'] = 'components/com_rsblog/assets/images/blog/' . $image;
			}
        }
        else if ($component_type == "virtuemart") {
            $query = $db->getQuery(true);
            $query
                ->select($db->quoteName('file_url', 'image'))
                ->from($db->quoteName('#__virtuemart_medias', 'a'))
                ->join('INNER', $db->quoteName('#__virtuemart_product_medias', 'b') . ' ON (' . $db->quoteName('a.virtuemart_media_id') . ' = ' . $db->quoteName('b.virtuemart_media_id') . ')')
                ->where($db->quoteName($structure['id']) . ' = ' . $db->quote($component_id))
                ->where($db->quoteName('a.published') . ' = 1')
                ->order($db->quoteName('b.ordering') . ' ASC')
                ->setLimit('1');

            $db->setQuery($query);
            $result = $db->loadResult();
			if (isset($result))
			{
				$results['image'] = $result;
			} else {
				$results['image'] = "";
			}
        }
		else if ($component_type == "opencart") {
            $query = $db->getQuery(true);
            $query
                ->select($db->quoteName('image', 'image'))
                ->from($db->quoteName('oc_product', 'a'))
                ->join('INNER', $db->quoteName('oc_product_description', 'b') . ' ON (' . $db->quoteName('a.product_id') . ' = ' . $db->quoteName('b.product_id') . ')')
                ->where($db->quoteName('a.product_id') . ' = ' . $db->quote($component_id))
                ->setLimit('1');

            $db->setQuery($query);
            $result = $db->loadResult();
			if (isset($result))
			{
				$results['image'] = 'components/com_opencart/image/' . $result;
			} else {
				$results['image'] = "";
			}
        }
		else if ($component_type == "jticketing") {
            $query = $db->getQuery(true);
            $query
                ->select($db->quoteName('path'))
				->select($db->quoteName('source'))
                ->from($db->quoteName('#__tj_media_files', 'b'))
                ->join('INNER', $db->quoteName('#__tj_media_files_xref', 'c') . ' ON (' . $db->quoteName('b.id') . ' = ' . $db->quoteName('c.media_id') . ')')
				->join('INNER', $db->quoteName('#__jticketing_events', 'a') . ' ON (' . $db->quoteName('a.id') . ' = ' . $db->quoteName('c.client_id') . ')')
                ->where('a.id = ' . $db->quote($component_id))
				->where($db->quoteName('c.is_gallery') . ' = 0');

            $db->setQuery($query);
			$result = $db->loadAssoc();
			if (isset($result['source']) && isset($result['path']))
			{
				$results['image'] = $result['path'] . '/' . $result['source'];
			} else {
				$results['image'] = "";
			}
        }
        else if ($component_type == "hikashop") {
            $query = $db->getQuery(true);
            $query
                ->select($db->quoteName('file_path', 'image'))
                ->from($db->quoteName('#__hikashop_file', 'a'))
                ->where($db->quoteName('a.file_ref_id') . ' = ' . $db->quote($component_id))
                ->where($db->quoteName('a.file_type') . ' = "product"')
                ->order($db->quoteName('a.file_id') . ' ASC')
                ->setLimit('1');

            $db->setQuery($query);
			$result = $db->loadResult();
            if (isset($result))
			{
				$results['image'] = 'images/com_hikashop/upload/' . $result;
			}
			else {
				$results['image'] = "";
			}
        }
		else if ($component_type == "eshop") {
            $query = $db->getQuery(true);
            $query
                ->select($db->quoteName('product_image', 'image'))
                ->from($db->quoteName('#__eshop_products', 'a'))
                ->where($db->quoteName('a.id') . ' = ' . $db->quote($component_id))
                ->setLimit('1');

            $db->setQuery($query);
			$result = $db->loadResult();
            if (isset($result))
			{
				$results['image'] = 'media/com_eshop/products/' . $result;
			}
			else {
				$results['image'] = "";
			}
        }

		// Search the content for an image if this is not defined and needs to be done
		if ( ($results['image'] == '') && ($config_params->get('get_image_from_content')) ){
			preg_match('/< *img[^>]*src *= *["\']?([^"\']*)/i', $results['description'], $match);
			if (isset($match[1]) && $match[1] != '') {
				$results['image'] = $match[1];
			}
		}

		$removePluginShortcodes = $config_params->get('remove_plugin_shortcodes');
		if ($removePluginShortcodes && isset($results['description'])) {
			$results['description'] = preg_replace('/{(.*?)}/', '', $results['description']);
		}

		if (isset($results['description'])) {
			$results['description'] = strip_tags($results['description']); // Strip HTML tags from the description
		}

		return $results;
	}

	public static function getParamsfromResults($results)
	{
		if (!isset($results["title"])) {
			return false;
		}

		$config_params = TagzHelper::getParams();
		$maxCharsTitleFacebook = $config_params->get('fb_max_title_length');
		$maxCharsDescriptionFacebook = $config_params->get('fb_max_description_length');
		$maxCharsTitleTwitter = $config_params->get('twitter_max_title_length');
		$maxCharsDescriptionTwitter = $config_params->get('twitter_max_description_length');

		$fb_title = mb_substr($results["title"], 0, $maxCharsTitleFacebook);
		$fb_description = mb_substr($results["description"], 0, $maxCharsDescriptionFacebook);
		$fb_image = $results["image"];
		$twitter_title = mb_substr($results["title"], 0, $maxCharsTitleTwitter);
		$twitter_description = mb_substr($results["description"], 0, $maxCharsDescriptionTwitter);
		$twitter_image = $results["image"];

		$params = array("fb_title" => $fb_title, "fb_description" => $fb_description, "fb_image" => $fb_image, "twitter_title" => $twitter_title, "twitter_description" => $twitter_description, "twitter_image" => $twitter_image);

		return $params;
	}

	public static function storeTagInfo($component_id, $component_type, $params, $id)
	{
		$registry = new JRegistry();
		$registry->loadArray($params);
	    $params = (string)$registry;

		// Only insert if data is passed
		if ($component_type != '' && $component_id != 0)
		{
			$db = JFactory::getDbo();
			$query = $db->getQuery(true);

            if ($id === -1) // New Entry so Insert
            {
                $id = '';
                $values = array($db->quote('0'), $db->quote($component_type), $db->quote($component_id), $db->quote('0'), $db->quote($params));

                // Prepare the insert query.
                $query
		             ->insert($db->quoteName('#__tagz'))
                     ->values(implode(',', $values));
            }
            else { // Existing entry so Update

                $query
        			->update($db->quoteName('#__tagz'))
        			->set($db->quoteName('params') . ' = ' . $db->quote($params))
        			->where($db->quoteName('id') . ' = ' . $db->quote($id));
            }

			// cbs j3.x
			// Set the query using our newly populated query object and execute it.
			// $db->setQuery($query);
			// $db->execute();


			// if ($db->getErrorNum()) {
	    	// 	return JFactory::getApplication()->enqueueMessage($db->stderr(), 'error');
			// }

			try
			{
				$db->setQuery($query);
				$result = $db->execute();
			}
			catch (Exception $e)
			{
				$app->enqueueMessage(JText::_($e->getMessage()), 'error');
			}


		}
	}

    public static function getContentTypeStructure($type)
    {
        $structure = array();
		$params = TagzHelper::getParams();

        $id = 'id';
        $title = 'title';
        $image = 'images';
        $description = 'introtext';
        $defaultSort = 'a.modified';

        switch ($type) {
			case 'content':
				$description = $params->get('preferred_content_description', 'introtext');
				$table = 'content';
                break;
			case 'k2':
				$table = 'k2_items';
				break;
			case 'jticketing':
				$table = 'jticketing_events';
				$description = 'long_description';
				break;
			case 'rsblog':
				$table = 'rsblog_posts';
				$image = 'image';
				$defaultSort = 'a.modified_date';
				break;
			case 'zoo':
				$table = 'zoo_item';
				$title = 'name';
				$description = 'elements';
				break;
			case 'icagenda':
				$table = 'icagenda_events';
				$description = 'shortdesc';
				$image = 'image';
				break;
			case 'rseventspro':
				$table = 'rseventspro_events';
				$title = 'name';
				$description = 'description';
				$image = 'icon';
				$defaultSort = 'a.created';
				break;
			case 'mijovideos':
				$table = 'mijovideos_videos';
				$image = 'thumb';
				break;
			case 'virtuemart':
				$activeLanguageTag = str_replace('-', '_', strtolower(JFactory::getLanguage()->getTag()));
				$table = 'virtuemart_products_' . $activeLanguageTag;
				$id = 'virtuemart_product_id';
				$title = 'product_name';
				$description = 'product_desc';
				$defaultSort = 'a.virtuemart_product_id';
				break;
			case 'opencart':
				$table = 'oc_product_description';
				$id = 'product_id';
				$title = 'name';
				$description = 'description';
				$defaultSort = 'a.product_id';
				break;
			case 'eshop':
				$table = 'eshop_productdetails';
				$id = 'product_id';
				$title = 'product_name';
				$description = 'product_desc';
				$defaultSort = 'a.product_id';
				break;
			case 'eventbooking':
				$table = 'eb_events';
				$description = 'description';
				$image = 'image';
				$defaultSort = 'a.event_date';
				break;
			case 'jomclassifieds':
				$table = 'jomcl_adverts';
				$description = 'description';
				$defaultSort = 'a.updateddate';
				break;
			case 'easyblog':
				$table = 'easyblog_post';
				$description = 'intro';
				$image = 'image';
				break;
			case 'hikashop':
				$table = 'hikashop_product';
				$id = 'product_id';
				$description = 'product_description';
				$title = 'product_name';
				$defaultSort = 'product_modified';
				break;
			case 'menu':
				$table = 'menu';
				$title = 'alias';
				$description = '';
				$image = '';
				$defaultSort = 'a.menutype';
				break;
			default:
				$table = 'none';
				break;
		}

        $structure['id'] = $id;
		$structure['table'] = $table;
        $structure['title'] = $title;
        $structure['description'] = $description;
        $structure['image'] = $image;
        $structure['defaultSort'] = $defaultSort;

        return $structure;
    }

	public static function getPreviewDiv($component_id, $params, $network)
	{
		$baseUrl = JURI::root();
		$titleVar = $network . "_title";
		$title = $params->$titleVar;
		$descriptionVar = $network . "_description";
		$description = $params->$descriptionVar;
		$imageVar = $network . "_image";
		$imageUrl = $params->$imageVar;
		if (strpos($imageUrl, 'http') === false) { // only add the base url if no http has been added already (e.g. external website)
			$imageUrl = $baseUrl . $params->$imageVar;
		}

		$joomla_version = substr(JVERSION,0,1);
		$display_style =  ( $joomla_version < 4 ) ? ' style="display:none" ': '';

		$html = '<div '. $display_style .'>
			 <div id="preview_'. $network . "_" . $component_id .'">
			 	<div class="tagz_preview_container_'. $network .'">';

 		$html .= '
	 				<div class="tagz_preview_image_'. $network .'">
	 					<img src="' . $imageUrl . '">
	 				</div>
	         		<div class="tagz_preview_content_'. $network .'">
	             		<div class="tagz_preview_content_title_'. $network .'">'. $title .'</div>
	             		<div class="tagz_preview_content_text_'. $network .'">'. $description .'</div>
	         		</div>
	     		</div>

	 		 </div>
		 </div>';

		 return $html;
	}

	public static function getItemsLockState($type)
	{
		$db = JFactory::getDBO();

		$query = $db->getQuery(true)
			->select($db->quoteName(array('component_id', 'lock_tag')))
			->from($db->quoteName('#__tagz'))
			->where($db->quoteName('component_type') . ' = ' . $db->quote($type));
		$db->setQuery($query);

		$results = $db->loadAssocList('component_id', 'lock_tag');

		return $results;
	}

	public static function getItemsParams($type)
	{
		$db = JFactory::getDBO();

		$query = $db->getQuery(true)
			->select($db->quoteName(array('component_id', 'params')))
			->from($db->quoteName('#__tagz'))
			->where($db->quoteName('component_type') . ' = ' . $db->quote($type));
		$db->setQuery($query);

		$results = $db->loadAssocList('component_id', 'params');

		return $results;
	}

	public static function getEditItemLink($type)
    {
        switch ($type) {
			case 'content':
				$link = 'index.php?option=com_content&view=article&task=article.edit&layout=edit&id=';
				break;
			case 'k2':
				$link = 'index.php?option=com_k2&view=item&cid=';
				break;
			case 'zoo':
				$link = 'index.php?option=com_zoo&controller=item&changeapp=1&task=edit&cid%5B%5D=';
				break;
			case 'icagenda':
				$link = 'index.php?option=com_icagenda&task=event.edit&id=';
				break;
			case 'rsblog':
				$link = 'index.php?option=com_rsblog&view=post&layout=edit&id=';
				break;
			case 'mijovideos':
				$link = 'index.php?option=com_mijovideos&view=videos&task=edit&cid[]=';
				break;
			case 'virtuemart':
				$link = 'index.php?option=com_virtuemart&view=product&task=edit&virtuemart_product_id=';
				break;
			case 'opencart':
				$link = 'index.php?option=com_opencart&route=catalog/product/edit&product_id=';
				break;
			case 'eshop':
				$link = 'index.php?option=com_eshop&task=product.edit&cid[]=';
				break;
			case 'eventbooking':
				$link = 'index.php?option=com_eventbooking&view=event&id=';
				break;
			case 'rseventspro':
				$link = 'index.php?option=com_rseventspro&task=event.edit&id=';
				break;
			case 'easyblog':
				$link = 'index.php?option=com_easyblog&view=composer&tmpl=component&uid=';
				break;
			case 'hikashop':
				$link = 'index.php?option=com_hikashop&ctrl=product&task=edit&cid[]=';
				break;
			case 'jomclassifieds':
				$link = 'index.php?option=com_jomclassifieds&view=adverts&task=edit&'. JSession::getFormToken() .'=1&cid[]=';
				break;
			case 'menu':
				$link = 'index.php?option=com_menus&task=item.edit&id=';
				break;
		}

        return $link;
    }

    public static function addBackendCSS()
    {
        $document = JFactory::getDocument();

        $document->addStyleSheet(JUri::root() . 'administrator/components/com_tagz/assets/css/rh_admin.css');
        $document->addStyleSheet(JUri::root() . 'administrator/components/com_tagz/assets/css/sweetalert.css');
        $document->addStyleSheet(JURI::root() . 'administrator/components/com_tagz/assets/vendor/labelauty/jquery-labelauty.css');
        $document->addStyleSheet(JURI::root() . '/media/jui/css/icomoon.css');
    }

	public static function addBackendFastEditCSS()
    {
        $document = JFactory::getDocument();

        $document->addStyleSheet(JUri::root() . 'administrator/components/com_tagz/assets/css/tagz.css');
    }

    /**
     *  Get Plugin Parameters
     *
     *  @return  JRegistry
     */
    public static function getParams()
    {
        if (self::$params)
        {
            return self::$params;
        }

        JTable::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_tagz/tables');

        $table = JTable::getInstance('Config', 'TagzTable');
        $table->load('config');

        return (self::$params = new Registry($table->params));
    }

	/**
     *  Get Enabled Extensions
     *
     *  @return  array
     */
    public static function getEnabledExtensions()
	{
		$supportedExtensions = array('com_k2', 'com_virtuemart', 'com_easyblog', 'com_jomclassifieds', 'com_hikashop', 'com_rseventspro', 'com_zoo', 'com_jticketing', 'com_icagenda', 'com_eventbooking', 'com_eshop', 'com_rsblog', 'com_mijovideos', 'com_opencart');
		$enabledExtensions = array();

		$db = JFactory::getDBO();

		foreach ($supportedExtensions as &$extension) {
			$query = $db->getQuery(true)
				->select('e.enabled')
				->from('#__extensions AS e')
				->where('e.element = "'. $extension .'"')
				->where('e.type = "component"');
			$db->setQuery($query);
			$extensionEnabled = $db->loadResult();

			if ($extensionEnabled == 1) { // Extension is installed and enabled
				array_push($enabledExtensions, $extension);
			}
		}

		return $enabledExtensions;
	}

    public static function addBackendJS()
    {
        $document = JFactory::getDocument();

        $document->addScript(JURI::root() . 'administrator/components/com_tagz/assets/js/admin.js');
        $document->addScript(JURI::root() . 'administrator/components/com_tagz/assets/js/sweetalert.min.js');
        $document->addScript(JURI::root() . 'administrator/components/com_tagz/assets/js/jquery.loading-indicator.js');
        $document->addScript(JURI::root() . 'administrator/components/com_tagz/assets/vendor/labelauty/jquery-labelauty.js');
        $document->addScript(JURI::root() . 'administrator/components/com_tagz/assets/vendor/nestable/jquery.nestable.js');

        $document->addScriptDeclaration('
        	window.twttr = (function (d, s, id) {
        	  var t, js, fjs = d.getElementsByTagName(s)[0];
        	  if (d.getElementById(id)) return;
        	  js = d.createElement(s); js.id = id;
        	  js.src= "https://platform.twitter.com/widgets.js";
        	  fjs.parentNode.insertBefore(js, fjs);
        	  return window.twttr || (t = { _e: [], ready: function (f) { t._e.push(f) } });
        	}(document, "script", "twitter-wjs"));
        ');

    }

    public static function addWrapperStart($page = '', $class='')
    {
        $formUrl = 'index.php?option=com_tagz';

        if ($page != '')
            $formUrl = 'index.php?option=com_tagz&' . $page;

		$enabledExtensions = TagzHelper::getEnabledExtensions();

		// Set the wrapper height based on the number of enabled extensions
		$min_height_wrapper = 650 + (count($enabledExtensions) * 50);

		$joomla_version = substr(JVERSION,0,1);

		if ($joomla_version == 4) {
			TagzHelper::fixFieldTooltips();
		}

		$html = '
        <form action="'. JRoute::_($formUrl) .'" method="post" name="adminForm" id="adminForm" class="'. $class .'">

        <div id="rh_wrapper_outer" class="joomla' . $joomla_version . '">
        	<div id="rh_wrapper" style="min-height:' . $min_height_wrapper . 'px">
        	    <header class="rh_header">
        	        <nav class="rh_navbar rh_minimal_navbar">
        	            <div class="rh_navbar-header bg-darker">
        	                <a class="rh_navbar-icon rh_text-brand">
        	                    <span class="rh_icon_text"></span>
        	                </a>
        	            </div>
        	            <a href="https://www.roosterz.nl" target="_blank" id="rh_logo_full" class="rh_logo fadeInTopBig animated_slow"></a>
        	        </nav>
        	    </header>

        		<div id="rh_wrapper_sides" class="rh_tabs">
        			<aside class="rh_left-side">
        				<section class="rh_sidebar">
        					<ul class="rh_sidebar-menu rh_sidebar-menu-minimal rh_tab-links">
        						<li id="type_content" class=""><a href="index.php?option=com_tagz&view=tagz&component_type=content"><i class="rh_icon-joomla"></i><span>'. JText::_('COM_TAGZ_ARTICLES') .'</span></a></li>';

		$shoppingIcons = array('virtuemart', 'hikashop', 'eshop', 'opencart');
		$eventIcons = array('rseventspro', 'jticketing', 'icagenda', 'eventbooking');
		$videoIcons = array('mijovideos');
		$blogIcons = array('rsblog');

		foreach ($enabledExtensions as &$extension) {
			$extensionName = substr($extension, 4); // Name is after com_
			$extensionIcon = $extensionName;
			if (in_array($extensionName, $shoppingIcons))
			{
				$extensionIcon = 'shopping-basket';
			}
			if (in_array($extensionName, $eventIcons))
			{
				$extensionIcon = 'calendar';
			}
			if (in_array($extensionName, $blogIcons))
			{
				$extensionIcon = 'doc-text';
			}
			if (in_array($extensionName, $videoIcons))
			{
				$extensionIcon = 'video';
			}

			
			$link = 'https://www.roosterz.nl/joomla-extensions/tagz';
			$target = "_blank";
			
			
			$html .= '			<li id="type_'. $extensionName .'" class=""><a href='.$link.' target='. $target .'><i class="rh_icon-'. $extensionIcon .'"></i><span>'. $extensionName .'</span>';
			
			$html .= '<div class="label label-warning" style="margin: 3px 0 0 3px; float:right; font-size: 8px;">PRO</div>';
			
			$html .= '</a></li>';

		}

		$html .= '
        						<li id="type_menu" class=""><a href="index.php?option=com_tagz&view=tagz&component_type=menu"><i class="rh_icon-menu"></i><span>'. JText::_('COM_TAGZ_MENU_ITEMS') .'</span></a></li>
        						<li id="type_config" class=""><a href="index.php?option=com_tagz&view=config"><i class="rh_icon-configure"></i><span>config</span></a></li>
        						<li><a target="_blank" href="https://docs.roosterz.nl/tagz"><i class="rh_icon-doc"></i><span>manual</span></a></li>
        						<li><a target="_blank" href="https://www.roosterz.nl/support/forum"><i class="rh_icon-forum"></i><span>forum</span></a></li>
        						<li><a target="_blank" href="https://extensions.joomla.org/extensions/extension/site-management/seo-a-metadata/tagz-open-graph"><i class="rh_icon-love" style="color:#FF69B4!important;"></i><span>review</span></a></li>
        						<li id="type_about" class=""><a href="index.php?option=com_tagz&view=about"><i class="rh_icon-about"></i><span>'. JText::_("COM_TAGZ_ABOUT") .'</span></a></li>';

								if (TagzHelper::checkAMPZNotInstalled()) {
									$html .= '<a target="_blank" rel="noopener" href="https://www.roosterz.nl/joomla-extensions/ampz" id="rh_ampz_ad"></a>';
								}
			$html .= '
        					</ul>
        				</section>
        			</aside>
        			<aside class="rh_right-side">
        				<div class="rh_tab-content fadeInLeft animated">
                            <div style="display: block; margin-top: 20px;" class="rh_tab active">
            ';

		echo $html;
    }

    public static function addWrapperEnd($type = "")
    {
        $active = "type_about";
        if ($type != "")
            $active = "type_" . $type;

        echo '
                            </div>
                        </div>
                    </aside>
                </div>
            </div>
        </div>
        <div>
            <input type="hidden" name="task" value="" />
            <input type="hidden" name="boxchecked" value="0" />
            '. JHtml::_('form.token') .'
         </div>
        </form>';

		$params = TagzHelper::getParams();

		$maxCharsTitleFacebook = $params->get('fb_max_title_length');
		$maxCharsDescriptionFacebook = $params->get('fb_max_description_length');
		$maxCharsTitleTwitter = $params->get('twitter_max_title_length');
		$maxCharsDescriptionTwitter = $params->get('twitter_max_description_length');
		$componentType = $type;

		$js = "
		var tagz = {};
		tagz.max_chars_title_facebook = $maxCharsTitleFacebook;
		tagz.max_chars_description_facebook = $maxCharsDescriptionFacebook;
		tagz.max_chars_title_twitter = $maxCharsTitleTwitter;
		tagz.max_chars_description_twitter = $maxCharsDescriptionTwitter;
		tagz.baseUrl = location.href.split('&view')[0];
		tagz.component_type = '$componentType';

		jQuery(document).ready(function($) {
			$('#$active').addClass(\"active\");
		});

		";

		JFactory::getDocument()->addScriptDeclaration($js);
    }

	/**
	 * Display field help text as tooltip in Joomla 4
	 *
	 * @return void
	 */
	public static function fixFieldTooltips()
	{
		// Run once
        static $run;

        if ($run)
        {
            return;
        }

        $run = true;

		$doc = \JFactory::getDocument();

		$doc->addStyleDeclaration('
			.form-text, .form-control-feedback {
				display:none;
			}
			.tooltip .arrow:before {
				border-top-color:#444;
				border-bottom-color:#444;
			}
			.tooltip-inner {
				text-align: left;
				background-color: #444;
				padding: 7px 9px;
				max-width:300px;
			}

			label.tTooltip::before, label.hasPopover::before {
			    background-color: #ffffff;
			    border: 1px solid #c1c1c1;
			    border-radius: 100%;
			    color: #929292;
			    content: "i";
			    display: inline-block;
			    float: left;
			    font-family: georgia;
			    font-size: 10px;
			    font-weight: bold;
			    height: 13px;
			    left: 0;
			    line-height: 12px;
			    position: relative;
			    margin-right: 5px;
			    text-align: center;
			    top: 2px;
			    -webkit-transition: all 200ms ease 0s;
			    transition: all 200ms ease 0s;
			    width: 13px;
			}
		');

		$doc->addScriptDeclaration('
			document.addEventListener("DOMContentLoaded", function() {
				initPopover();

				document.addEventListener("joomla:updated", initPopover);

				function initPopover(event) {
					var target = event && event.target ? event.target : document;
					var fields = target.querySelectorAll(".control-group");

					fields.forEach(function(field) {
						var desc = field.querySelector(".form-text");

						if (desc) {
							var label = field.querySelector("label");

							if (label) {
								label.classList.add("tTooltip");
								label.setAttribute("title", desc.innerHTML);
							}
						}
					});

					jQuery(target).find(".tTooltip").tooltip({
						placement: "top",
						html: true,
						delay: {
							show: 200
						}
					});
				}
			});
		');
	}

    public static function getTagzPluginUrl()
    {
        $db = JFactory::getDbo();

        $query = $db->getQuery(true)
        	->select('*')
        	->from($db->quoteName('#__extensions'))
        	->where($db->quoteName('type') . ' = ' . $db->quote('plugin'))
        	->where($db->quoteName('folder') . ' = ' . $db->quote('system'))
        	->where($db->quoteName('element') . ' = ' . $db->quote('tagz'));
        $db->setQuery($query);
        $plugin = $db->loadObject();

        $tagz_plugin_url = 'index.php?option=com_plugins&task=plugin.edit&extension_id=' . $plugin->extension_id;

        return $tagz_plugin_url;
    }

}
